#
# spec file for package gajim
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.1
Name:           gajim
Version:        1.1.3
Release:        bp155.2.10
Summary:        XMPP client written in Python and Gtk3
License:        GPL-3.0-only
Group:          Productivity/Networking/Talk/Clients
URL:            https://gajim.org/
Source:         https://gajim.org/downloads/%{_version}/%{name}-%{version}.tar.bz2
Patch:          ssl_use_system_certs.patch
BuildRequires:  ca-certificates-mozilla
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  p11-kit-devel
BuildRequires:  pkgconfig
BuildRequires:  python3 >= 3.5.0
BuildRequires:  python3-nbxmpp >= 0.6.10
BuildRequires:  python3-precis-i18n >= 1.0.0
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       ca-certificates-mozilla
Requires:       python3 >= 3.5.0
Requires:       python3-cairo
Requires:       python3-cssutils >= 1.0.2
Requires:       python3-docutils
Requires:       python3-gobject-Gdk
Requires:       python3-gobject-cairo
Requires:       python3-nbxmpp >= 0.6.9
Requires:       python3-precis-i18n >= 1.0.0
Requires:       python3-pyOpenSSL >= 0.12
Requires:       python3-pycurl
Requires:       python3-xml
Recommends:     %{name}-lang
# OMEMO encryption
Recommends:     gajim-plugin-omemo
Recommends:     python3-axolotl
# End-to-end encryption.
Recommends:     python3-pycrypto
# zeroconf support.
Suggests:       dbus-1-glib
# Idle module.
Suggests:       libXss1
BuildArch:      noarch
%if 0%{?suse_version} >= 1500
Requires:       python3-Pillow
Requires:       python3-dbus-python
Requires:       python3-keyring
# GPG encryption.
Recommends:     python3-python-gnupg
%else
Requires:       dbus-1-python3
# WebP avatars.
Recommends:     python3-Pillow
# GPG encryption.
Recommends:     python3-gnupg
# Password storage.
Recommends:     python3-keyring
%endif

%description
Gajim is a Jabber/XMPP client. It works with MATE and GNOME, but does
require neither to run.

Features:
 * Tabbed chat window and single window modes.
 * Group chat support (with Multi-User Chat protocol), invitation,
   chat to group chat transformation, minimise group chat to roster.
 * Emoticons, avatars, PEP (user activity, mood and tune).
 * Audio / video conferences.
 * File transfer, room bookmarks.
 * Metacontacts support.
 * Trayicon, speller, extended chat history functionalities.
 * TLS, GPG and End-To-End encryption support (with SSL legacy support).
 * Transport registration support.
 * Service discovery including nodes, user search.
 * Wikipedia, dictionary and search engine lookup.
 * Multiple accounts support.
 * DBus capabilities. Read more information.
 * XML console.
 * Link local (bonjour / zeroconf), BOSH.
 * Other features via plugins.

%lang_package

%prep
%setup -q
%autopatch -p1
sed -i '/^Keywords/d' data/org.gajim.Gajim.desktop.in

# FIXME: Some leftover.
rm gajim/data/plugins/plugin_installer/config_dialog.ui~

%build
python3 setup.py build

%install
python3 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

mkdir -p %{buildroot}%{_datadir}/
mv %{buildroot}{%{python3_sitelib}/%{name}/data,%{_datadir}/%{name}}/
ln -s %{_datadir}/%{name} %{buildroot}%{python3_sitelib}/%{name}/data

%suse_update_desktop_file -r org.gajim.Gajim Network InstantMessaging
%fdupes %{buildroot}%{_prefix}/
%find_lang %{name}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%license COPYING
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-*
%{_datadir}/applications/*%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/*%{name}*.*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/*%{name}*.appdata.xml
%{_mandir}/man?/%{name}*%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sun Jan  5 2020 Benoît Monin <benoit.monin@gmx.fr>
- add ssl_use_system_certs.patch (boo#1159017):
  always use the system certificates and remove the provided one,
  fix build with newer ca-certificates bundle
* Thu May 23 2019 mvetter@suse.com
- Update to 1.1.3:
  New:
  * Add a mobile phone indicator to the chat window
  * Rework HTTPUpload dialog
  * Add a "paste as quote" option to the message input
  Bug fixes:
  * #8822 Fix memory leak when using spell checker
  * #9514 Fix jingle filetransfers not working in some circumstances
  * #9573 Dont leak DNS query when connecting over proxy
  * #9578 Determine Windows version more reliably
  * #9622 Fix an error while quitting Gajim
  * #9633 Fix an error while sending a file
  * #9637 Restore window size correctly on wayland
  * #9660 GPG Agent setting is ignored
  * #9645 Make zeroconf IPV6 compatible
  * Improve dark theme colors
  * Fix access to GnuPG keys
  * Use UUID4 item ids for pubsub posts
  * Dont send invalid show values
  * Various smaller improvements
* Thu Jan 31 2019 mvetter@suse.com
- Require python3-nbxmpp >= 0.6.9 (boo#1123247)
* Tue Jan 22 2019 liedke@rz.uni-mannheim.de
- Update to 1.1.2:
  * #9518 Windows: Pressing "^" yields "^^"
  * #9522 Windows: Switching keyboard layouts leads to a crash
  * #9525 Windows/Mac: Links are not clickable in the About dialog
  * #9535 Jingle Audio: Update codecs
  * #9537 DiscoveryWindow: Fix bookmarking a group chat
  * DBus: Correctly raise NewMessage signal
  * Clicking on tray notifications does not open the chat
* Wed Jan  2 2019 liedke@rz.uni-mannheim.de
- Update to 1.1.1:
  * 8362 DBus: Incorrect unread message count
  * 9427 Placeholder not cleared if pasting text into message input
  * 9444 Determine the delay timestamp correctly when using mam:1
  * 9453 Fix opening links inside the group chat subject (MacOS/Windows)
  * 9465 Allow the full range of possible nicknames in group chats
  * 9067 Gajim crashes when receiving xhtml messages
  * 9096 Error when clicking on a subscription notification
  * 9446 Chatstate error in MUC conversation
  * 9471 Conversation Textview: Error on key press
  * 9472 Handle presences without from attr correctly
  * 9473 Error when creating a new group chat
  * 9491 Identify group chat subject changes correctly
  * 9496 Error on MUC roster selection change
  * Determine soundplayer correctly on unix systems
  * In some circumstances plugins could not be deleted
  * Show correct contact status on tabs
  * Dont answer group chat receipt requests
  * Fix receipts for private messages
  * Pressing the back button in the Accounts window leads to an error
  * Better handle not available keyring backends
  * Dont show incorrect contact on private messages
  * Join group chat menu is disabled when there are no bookmarks
  * Error on start chat menu action
  * Error when opening sign-in/out notification
  * Copying text does not work with different keyboard layouts
* Mon Nov 19 2018 opensuse_buildservice@ojkastl.de
- Add Requires for python3-precis-i18n (boo#1116161).
* Fri Nov  9 2018 frede@b1-systems.de
- Add Recomment python3-axolotl for OMEMO Encryption
* Thu Nov  8 2018 mvetter@suse.com
- Update to 1.1.0:
  * Remove support for XEP-0091
  * 8968 Windows: Gajim loads DLLs from wrong location
  * 9322 Error when adding contact
  * 9357 Acquire sleep inhibtor correctly after sleep
  * 9385 Ignore invalid bookmarks
  * 9386 Discovery: Browsing nodes without identity
  * 9393 Error when parsing invalid timestamps
  * 9398 Error on jingle file transfer
- For complete ChangeLog from 1.0.99 and 1.0.99.1 please see
  installed ChaneLog file
- Remove dependency: python3-avahi
- Add dependency: python3-cssutils >= 1.0.2
* Mon Sep 24 2018 sor.alexei@meowr.ru
- Add some missing dependencies (boo#1109355).
* Wed May 23 2018 sor.alexei@meowr.ru
- Symlink the system PEM certfiicate to the path where
  Plugin Installer expects it to be instead of patching
  Plugin Installer as it can be updated locally unpatched and thus
  fail to work (boo#1094343).
- Remove gajim-do_not_ship_certificate.patch.in: no longer needed.
* Sat May 19 2018 mvetter@suse.com
- Update to 1.0.3:
  * bug 8296 Fix errors on roster updates after stream management resume
  * bug 9106 Convert font weight from pango to css values
  * bug 9124 Bring ChatControl to front when notification is clicked
  * Set no-store hint on groupchat chatstates
  * Dont show OOB uri if message body is the same
  * Add missing bybonjour dependency for Windows zeroconf
- Remove Require for pyasn1: not needed anymore
* Mon May 14 2018 frede@b1-systems.de
- Fixed dependency in spec file on python3 >= 3.5.0:
  * since Leap 42.3 and SLES 12 have only 3.4.6 they will not work
- Fixed dependency in spec file on python3-nbxmpp 0.6.5:
  * changed the also the required not only build-required
* Sat May 12 2018 tbro@opensuse.org
- Fixed dependency in spec file on python3-nbxmpp 0.6.5:
  * With python3-nbxmpp 0.6.4 the newest version of gajim broke
* Thu May  3 2018 sor.alexei@meowr.ru
- Update to version 1.0.2:
  * Server name was rejected for group chat bookmarks.
  * setup.py install missed some files if used with "--skip-build".
  * Password was sometimes stored in plaintext.
  * Do not show an error when receiving invalid avatars.
  * Fix no Licence in the About dialogue.
  * Encode filenames before sending.
  * Catch invalid IQ stanzas and log them.
  * XMPP logo in "Add New Contact" window instead Gajim logo.
  * Mark some strings as translatable.
  * Fix an error on file send completion.
  * Removing a bookmark caused an error.
  * Avatar is deleted when updating vCard.
  * Account label didn't change in tooltip of notification area
    icon.
  * Placeholder text didn't disappear.
  * Fix History Manager search.
  * Proxy comobobox in accounts/connections didn't get updated
    after ManageProxies.
  * Fix a problem receiving files.
  * Notification never autohides in gnome.
  * Correctly reload Plugins.
  * Save history export with utf8 encoding.
  * Dont allow plain BOSH by default.
* Sun Apr  8 2018 dev@stellardeath.org
- Add the python3-axolotl package to recommends to make OMEMO work
  out of the box.
* Mon Apr  2 2018 sor.alexei@meowr.ru
- Update to version 1.0.1:
  * Improve MAM support.
  * Image preview in the file chooser dialogue.
  * Groupchat: Set minimise on auto join default to true.
  * Delete a bookmark when we destroy a room.
  * Fix account deletion.
  * Fix custom font handling.
  * Fix OpenPGP message decryption.
  * Fix window position restore on multi-head setups.
  * Fix scrolling in message window.
* Sat Mar 17 2018 sor.alexei@meowr.ru
- Update to version 1.0.0:
  * Ported to GTK+3 / Python3.
  * Integrate HTTPUpload.
  * Add Navigation buttons in History Window.
  * Improvements for HiDPI Screens.
  * Depend on the python keyring package for password storage.
  * Lots of refactoring.
  * New Emoji support.
  * New Chat Window design.
  * New StartChat Window (Ctrl+N).
  * New ServerInfo Window.
  * AccountWindow Redesign.
  * Move some encryption code out into Plugins (see PGP Plugin,
    Esessions Plugin).
  * Add mam:1 and mam:2 support (mam:0 was removed).
  * Add MAM for MUCs support.
  * Add support for showing XEP-0084 Avatars.
  * Add support for geo: URIs.
  * Add xmpp URI handling directly in Gajim.
  * Remove Gajim-Remote.
  * Remove XEP-0012 (Last Activity).
  * Remove XEP-0136 (Message Archiving).
  * Add XEP-0156 (Discovering Alternative XMPP Connection Methods).
  * Add XEP-0319 (Last User Interaction in Presence).
  * Add XEP-0368 (SRV records for XMPP over TLS).
  * Add XEP-0380 (Explicit Message Encryption).
  * Add Jingle FT:5 support.
  * Lots of other small bugfixes.
- Rebase gajim-do_not_ship_certificate.patch.in.
- Update requirements and recommendations:
  also require things that are not strictly required if they are
  harmless and definitely available.
* Wed Dec 13 2017 frede@b1-systems.de
- Add Requires:       python-nbxmpp >= 0.6.1
* Tue Dec  5 2017 mvetter@suse.com
- Update to 0.16.9:
  * Improve Zeroconf behavior
  * Fix showing normal message event
  * remove usage of OpenSSL.rand
  * a few minor bugfixes
- Update of icon cache and desktop file only in case of older
  distribution
* Mon Jul 10 2017 jengelh@inai.de
- Trim filler wording from description.
* Tue Jul  4 2017 vilene@posteo.net
- Update to version 0.16.8:
  * Fix rejoining MUCs after connection loss
  * Fix Groupchat invites
  * Fix encoding problems with newer GnuPG versions
  * Fix old messages randomly reappearing in the chat window
  * Fix some problems with IBB filetransfer
  * Make XEP-0146 Commands opt-in
  * Improve sending messages to your own resources
  * Improve reliability of delivery recipes
  * Many minor bugfixes
- Add gajim-do_not_ship_certificate.patch.in: Do not package
  bundled PEM certificate, use one provided by package
  `ca-certificates-mozilla' instead.
- Remove gajim-0.16.7-default-disable-xep-0146.patch: Not needed
  anymore, patch applied upstream.
* Mon May 29 2017 sor.alexei@meowr.ru
- Add gajim-0.16.7-default-disable-xep-0146.patch by
  Philipp Hörist: Add a config option to activate XEP-0146 commands
  (commit cb65cfc, CVE-2016-10376, bsc#1041163).
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 0.16.7:
  * Better compatibility with XEP-0191: Blocking Command.
  * Gajim now depends on python-gnupg for PGP encryption.
  * Remove usage of demandimport.
  * Many minor bugfixes.
- Move python-farstream-0_1 to Suggests.
- Correct the licence to GPL-3.0.
* Thu Oct 13 2016 sor.alexei@meowr.ru
- Update to version 0.16.6:
  * Fix using gpg2.
  * Improve message receips usage.
  * Improve roster filtering.
  * Fix several minor bugs.
- Remove gajim-remote-dont-show.patch: merged upstream.
* Tue May 24 2016 mvetter@suse.com
- Add gajim-remote-dont-show.patch:
  gajim-remote is cli only. Dont list it in menus.
- If python-gstreamer-0_10 is installed the error message
  'ImportError: could not import gst' is not shown.
  See: https://trac.gajim.org/ticket/7836
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.16.5:
  * Improve MAM implementation.
  * Improve security on connexion and for roster managment
    (rh#1295475, bsc#960668, CVE-2015-8688)
  * Ability for emoticons to be sorted in menu.
* Sun Sep 27 2015 sor.alexei@meowr.ru
- Update to 0.16.4:
  * Fix trusting GPG keys.
  * Ability to disable synchronisation of logs with server.
  * Improve MAM usage.
* Sun Aug  2 2015 sor.alexei@meowr.ru
- Update to 0.16.3:
  * Fix reading secret file.
  * Fix reconnection after suspend.
  * Fix sending GPG-encrypted file to non-trusted key.
* Sat Jul 25 2015 sor.alexei@meowr.ru
- Update to 0.16.2:
  * Improve Zeroconf (Avahi) with IPv6.
  * Fix errors with GnuPG.
  * Minor fixes and improvements.
* Sun Mar  1 2015 sor.alexei@meowr.ru
- Update to 0.16.1:
  * Fix sending Zeroconf messages.
  * Make ipython compatible to version >= 1.0.
  * Support XEP-0313 MAM.
  * Minor fixes and improvements.
* Tue Feb 10 2015 sor.alexei@meowr.ru
- Add python-farstream-0_1 optional dependency.
* Sat Oct 11 2014 sor.alexei@meowr.ru
- Update to 0.16:
  * Improve File transfer support by adding Jingle file transfer.
  * Use external python-nbxmpp library.
  * improve security.
  * Improve audio / Video calls and add screensharing feature.
  * Support audio under windows.
  * Support systemd-logind.
  * Support XEP-0308 Last message correction.
  * Support XEP-0224 Attention.
  * Support XEP-0191 Blocking command.
  * Support XEP-0249 Direct Invitation.
  * Better RTL languages support.
  * Use host command to resolve SRV records if it is available.
- Completely review dependencies.
- Spec cleanup.
- Separate gajim-lang package.
- Purge --enable-{remote ,gtkspell,idle,trayicon} from configure
  options and trust the defaults.
- Replace Python bytecode generation script with a more verbose one.
- Generate icon cache after package installation.
- Enable Python site packages.
* Mon May 27 2013 zaitor@opensuse.org
- Update to version 0.15.4:
  * Fix usage of OTR plugin
  * Fix connection to non-SSL server
  * Fix receiving GPG-encrypted messages while offline.
- Changes from version 0.15.3:
  * Better handling of SSL errors
  * Better handling of canceling file transfer
  * Improve farstream calls
  * Minor fixes and improvements
- Changes from version 0.15.2:
  * Show punycode encoded urls if they contain non-ascii chars
  * Fix crash when pressing Esc in chat window
  * Support Network Manager 0.9
  * decrypt GPG messages in the correct order
- Changes from version 0.15.1:
  * Switch from python-farsight to python-farstream
  * improve performances
  * Fix roster filter with unicode chars
  * Fix connection to msn jabber server
  * Fix some GPG issues
  * Fix other small issues
- Drop gajim-CVE-2012-2093-fix_insecure_temp_file_for_latex.patch,
  fixed upstream.
- Add python-farstream Recommends, fixes bnc#821233.
* Thu May 24 2012 pascal.bleser@opensuse.org
- add gajim-CVE-2012-2093-fix_insecure_temp_file_for_latex.patch
  (CVE#2012-2093) which fixes insecure usage of temporary files for rendering
  LaTeX markup, see also bnc#763452
* Wed May 23 2012 pascal.bleser@opensuse.org
- update to 0.15
* Sat Sep 10 2011 pascal.bleser@opensuse.org
- changed Requires:python-gstreamer to python-gstreamer-0_10, thanks to Peter
  von Arx for reporting
* Sat Sep  3 2011 prusnak@opensuse.org
- updated to 0.14.4
  * Fix translation issue
  * other minor fixes
- updated to 0.14.3
  * Fix history viewer
  * Fix closing roster window
  * Prevent some erros with metacontacts
- updated to 0.14.2
  * Fix CPU usage when testing file transfer proxies
  * Fix invalid XML char regex
  * Fix subscription request window handling
  * Fix URL display in chat message banner
  * Other minor bugfixes
- updated to 0.14.1
  * Fix changing account name
  * Fix sending XHTML
  * Fix GnomeKayring usage
  * Fix some GPG bugs
  * Minor bugfixes
- updated to 0.14
  * Jingle audio / video chat
  * Improve Startup time
  * Copy emoticons, LaTeX expressions when they are selected
  * Fix status icon transparency by using gtk.statusicon
  * Groupchat auto-rejoin
  * geolocation (with geoclue)
  * use XDG standards
  * SCRAM-SHA-1 and SASL EXTERNAL authentication
  * MUC captcha
  * Lots of refactoring
- spec cleanup
* Sun May 16 2010 bernhard@bwalle.de
- update to 0.13.4
  * Fix some TLS connection
  * Don't raise a lot of "DB Error" dialog
  * Fix contact synchronisation
  * Add japanese translation
  * Minor fixes
  * Fix facebook xmpp server connection
  * Fix copy / paste with Ctrl+C on non-latin keyboard
  * Fix sending PEP information when connecting
  * Fix parsing HTML messages that have ascii markup
  * Fix some translations
  * Fix string comparison according to locales
  * Fix some gnomekeyring glitches
  * Copy emoticons when we copy / paste in conversations
- convert changelog to SUSE-style changes file
* Sat May 15 2010 pascal.bleser@opensuse.org
- update to 0.13.1:
  * adds BOSH connection
  * adds roster versioning
  * adds the ability to send contacts
  * adds a GUI to send XHTML messages
  * adds pubsub storage (for bookmarks)
* Sat May 15 2010 pascal.bleser@opensuse.org
- add patch to fix #4788: Error receiving OpenPGP encrypted messages with
  utf-8 characters
* Sat May 15 2010 pascal.bleser@opensuse.org
- update to 0.12.1:
  * fix filetransfer
  * updated german translation
  * fix click on notifications when text string is empty
  * improve systray popup menu
* Sat May 15 2010 pascal.bleser@opensuse.org
- license changed to GPL version 3
- scrapped old %%%%changelog entries
- moved to OBS
- update to 0.12:
  * support for End-To-End encryption and SSL certificate verification for security
  * support for transforming a one-to-one chat into a group chat
  * ability to minimize group chats in the roster for group chat management
  * single window mode
  * support for PEP (Personal Eventing Protocol)
  * support for Latex for the GUI
  * security improvements: Kerberos (GSSAPI) SASL Authentication mechanism
  * improve GUI of some windows
  * fix handling of invalid XML
  * fix freeze on connection
  * security improvements: End-to-End encryption, SSL certificate verification
  * ability to minimize groupchats in roster
  * block/Unblock contacts directly from roster
  * much faster contact list
* Sat May 15 2010 pascal.bleser@opensuse.org
- new upstream version
